==> boo_0.8.2.2960+dfsg.orig.tar.gz: boo-0.8.2.2960+dfsg/src/Boo.Lang.Parser/WSABooExpressionLexerTokenTypes.cs <==
﻿#region license
// Copyright (c) 2003, 2004, 2005 Rodrigo B. de Oliveira (rbo@acm.org)
// All rights reserved.
// 
// Redistribution and use in source and binary forms, with or without modification,
// are permitted provided that the following conditions are met:
// 
//     * Redistributions of source code must retain the above copyright notice,
//     this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above copyright notice,
//     this list of conditions and the following disclaimer in the documentation
//     and/or other materials provided with the distribution.
//     * Neither the name of Rodrigo B. de Oliveira nor the names of its
//     contributors may be used to endorse or promote products derived from this
//     software without specific prior written permission.
// 
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
// DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE
// FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
// DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
// SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
// CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
// OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
// THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#endregion


// $ANTLR 2.7.5 (20050517): "src/Boo.Lang.Parser/wsabooel.g" -> "WSABooExpressionLexer.cs"$

namespace Boo.Lang.Parser
{
	public class WSABooExpressionLexerTokenTypes
	{
		public const int EOF = 1;
		public const int NULL_TREE_LOOKAHEAD = 3;
		public const int ELIST = 4;
		public const int DLIST = 5;
		public const int ESEPARATOR = 6;
		public const int ABSTRACT = 7;
		public const int AND = 8;
		public const int AS = 9;
		public const int BREAK = 10;
		public const int CONTINUE = 11;
		public const int CALLABLE = 12;
		public const int CAST = 13;
		public const int CHAR = 14;
		public const int CLASS = 15;
		public const int CONSTRUCTOR = 16;
		public const int DEF = 17;
		public const int DESTRUCTOR = 18;
		public const int DO = 19;
		public const int ELIF = 20;
		public const int ELSE = 21;
		public const int END = 22;
		public const int ENSURE = 23;
		public const int ENUM = 24;
		public const int EVENT = 25;
		public const int EXCEPT = 26;
		public const int FAILURE = 27;
		public const int FINAL = 28;
		public const int FROM = 29;
		public const int FOR = 30;
		public const int FALSE = 31;
		public const int GET = 32;
		public const int GOTO = 33;
		public const int IMPORT = 34;
		public const int INTERFACE = 35;
		public const int INTERNAL = 36;
		public const int IS = 37;
		public const int ISA = 38;
		public const int IF = 39;
		public const int IN = 40;
		public const int NOT = 41;
		public const int NULL = 42;
		public const int OF = 43;
		public const int OR = 44;
		public const int OVERRIDE = 45;
		public const int NAMESPACE = 46;
		public const int PUBLIC = 47;
		public const int PROTECTED = 48;
		public const int PRIVATE = 49;
		public const int RAISE = 50;
		public const int REF = 51;
		public const int RETURN = 52;
		public const int SET = 53;
		public const int SELF = 54;
		public const int SUPER = 55;
		public const int STATIC = 56;
		public const int STRUCT = 57;
		public const int THEN = 58;
		public const int TRY = 59;
		public const int TRANSIENT = 60;
		public const int TRUE = 61;
		public const int TYPEOF = 62;
		public const int UNLESS = 63;
		public const int VIRTUAL = 64;
		public const int PARTIAL = 65;
		public const int WHILE = 66;
		public const int YIELD = 67;
		public const int TRIPLE_QUOTED_STRING = 68;
		public const int EOS = 69;
		public const int NEWLINE = 70;
		public const int DOUBLE_QUOTED_STRING = 71;
		public const int SINGLE_QUOTED_STRING = 72;
		public const int ID = 73;
		public const int LBRACK = 74;
		public const int RBRACK = 75;
		public const int LPAREN = 76;
		public const int RPAREN = 77;
		public const int ASSIGN = 78;
		public const int SUBTRACT = 79;
		public const int COMMA = 80;
		public const int ASSEMBLY_ATTRIBUTE_BEGIN = 81;
		public const int DOT = 82;
		public const int COLON = 83;
		public const int MULTIPLY = 84;
		public const int SPLICE_BEGIN = 85;
		public const int NULLABLE_SUFFIX = 86;
		public const int BITWISE_OR = 87;
		public const int LBRACE = 88;
		public const int RBRACE = 89;
		public const int QQ_BEGIN = 90;
		public const int QQ_END = 91;
		public const int INPLACE_BITWISE_OR = 92;
		public const int INPLACE_BITWISE_AND = 93;
		public const int INPLACE_SHIFT_LEFT = 94;
		public const int INPLACE_SHIFT_RIGHT = 95;
		public const int CMP_OPERATOR = 96;
		public const int GREATER_THAN = 97;
		public const int LESS_THAN = 98;
		public const int ADD = 99;
		public const int EXCLUSIVE_OR = 100;
		public const int DIVISION = 101;
		public const int MODULUS = 102;
		public const int BITWISE_AND = 103;
		public const int SHIFT_LEFT = 104;
		public const int SHIFT_RIGHT = 105;
		public const int EXPONENTIATION = 106;
		public const int INCREMENT = 107;
		public const int DECREMENT = 108;
		public const int ONES_COMPLEMENT = 109;
		public const int INT = 110;
		public const int LONG = 111;
		public const int RE_LITERAL = 112;
		public const int DOUBLE = 113;
		public const int FLOAT = 114;
		public const int TIMESPAN = 115;
		public const int LINE_CONTINUATION = 116;
		public const int SL_COMMENT = 117;
		public const int ML_COMMENT = 118;
		public const int WS = 119;
		public const int X_RE_LITERAL = 120;
		public const int ESCAPED_EXPRESSION = 121;
		public const int DQS_ESC = 122;
		public const int SQS_ESC = 123;
		public const int SESC = 124;
		public const int RE_CHAR = 125;
		public const int X_RE_CHAR = 126;
		public const int RE_ESC = 127;
		public const int DIGIT_GROUP = 128;
		public const int REVERSE_DIGIT_GROUP = 129;
		public const int ID_PREFIX = 130;
		public const int ID_LETTER = 131;
		public const int DIGIT = 132;
		public const int HEXDIGIT = 133;
		
	}
}

==> boo_0.9.2.3383+dfsg.orig.tar.gz: boo-0.9.2.3383+dfsg/src/Boo.Lang.Parser/WSABooExpressionLexerTokenTypes.cs <==
﻿#region license
// Copyright (c) 2003, 2004, 2005 Rodrigo B. de Oliveira (rbo@acm.org)
// All rights reserved.
// 
// Redistribution and use in source and binary forms, with or without modification,
// are permitted provided that the following conditions are met:
// 
//     * Redistributions of source code must retain the above copyright notice,
//     this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above copyright notice,
//     this list of conditions and the following disclaimer in the documentation
//     and/or other materials provided with the distribution.
//     * Neither the name of Rodrigo B. de Oliveira nor the names of its
//     contributors may be used to endorse or promote products derived from this
//     software without specific prior written permission.
// 
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
// DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE
// FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
// DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
// SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
// CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
// OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
// THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#endregion


// $ANTLR 2.7.5 (20050517): "src/Boo.Lang.Parser/wsabooel.g" -> "WSABooExpressionLexer.cs"$

namespace Boo.Lang.Parser
{
	public class WSABooExpressionLexerTokenTypes
	{
		public const int EOF = 1;
		public const int NULL_TREE_LOOKAHEAD = 3;
		public const int ELIST = 4;
		public const int DLIST = 5;
		public const int ESEPARATOR = 6;
		public const int ABSTRACT = 7;
		public const int AND = 8;
		public const int AS = 9;
		public const int BREAK = 10;
		public const int CONTINUE = 11;
		public const int CALLABLE = 12;
		public const int CAST = 13;
		public const int CHAR = 14;
		public const int CLASS = 15;
		public const int CONSTRUCTOR = 16;
		public const int DEF = 17;
		public const int DESTRUCTOR = 18;
		public const int DO = 19;
		public const int ELIF = 20;
		public const int ELSE = 21;
		public const int END = 22;
		public const int ENSURE = 23;
		public const int ENUM = 24;
		public const int EVENT = 25;
		public const int EXCEPT = 26;
		public const int FAILURE = 27;
		public const int FINAL = 28;
		public const int FROM = 29;
		public const int FOR = 30;
		public const int FALSE = 31;
		public const int GET = 32;
		public const int GOTO = 33;
		public const int IMPORT = 34;
		public const int INTERFACE = 35;
		public const int INTERNAL = 36;
		public const int IS = 37;
		public const int ISA = 38;
		public const int IF = 39;
		public const int IN = 40;
		public const int NOT = 41;
		public const int NULL = 42;
		public const int OF = 43;
		public const int OR = 44;
		public const int OVERRIDE = 45;
		public const int NAMESPACE = 46;
		public const int PUBLIC = 47;
		public const int PROTECTED = 48;
		public const int PRIVATE = 49;
		public const int RAISE = 50;
		public const int REF = 51;
		public const int RETURN = 52;
		public const int SET = 53;
		public const int SELF = 54;
		public const int SUPER = 55;
		public const int STATIC = 56;
		public const int STRUCT = 57;
		public const int THEN = 58;
		public const int TRY = 59;
		public const int TRANSIENT = 60;
		public const int TRUE = 61;
		public const int TYPEOF = 62;
		public const int UNLESS = 63;
		public const int VIRTUAL = 64;
		public const int PARTIAL = 65;
		public const int WHILE = 66;
		public const int YIELD = 67;
		public const int ID = 68;
		public const int TRIPLE_QUOTED_STRING = 69;
		public const int EOS = 70;
		public const int NEWLINE = 71;
		public const int DOUBLE_QUOTED_STRING = 72;
		public const int SINGLE_QUOTED_STRING = 73;
		public const int LBRACK = 74;
		public const int RBRACK = 75;
		public const int LPAREN = 76;
		public const int RPAREN = 77;
		public const int ASSIGN = 78;
		public const int SUBTRACT = 79;
		public const int COMMA = 80;
		public const int ASSEMBLY_ATTRIBUTE_BEGIN = 81;
		public const int DOT = 82;
		public const int COLON = 83;
		public const int MULTIPLY = 84;
		public const int SPLICE_BEGIN = 85;
		public const int NULLABLE_SUFFIX = 86;
		public const int BITWISE_OR = 87;
		public const int LBRACE = 88;
		public const int RBRACE = 89;
		public const int QQ_BEGIN = 90;
		public const int QQ_END = 91;
		public const int INPLACE_BITWISE_OR = 92;
		public const int INPLACE_EXCLUSIVE_OR = 93;
		public const int INPLACE_BITWISE_AND = 94;
		public const int INPLACE_SHIFT_LEFT = 95;
		public const int INPLACE_SHIFT_RIGHT = 96;
		public const int CMP_OPERATOR = 97;
		public const int GREATER_THAN = 98;
		public const int LESS_THAN = 99;
		public const int ADD = 100;
		public const int EXCLUSIVE_OR = 101;
		public const int DIVISION = 102;
		public const int MODULUS = 103;
		public const int BITWISE_AND = 104;
		public const int SHIFT_LEFT = 105;
		public const int SHIFT_RIGHT = 106;
		public const int EXPONENTIATION = 107;
		public const int INCREMENT = 108;
		public const int DECREMENT = 109;
		public const int ONES_COMPLEMENT = 110;
		public const int INT = 111;
		public const int LONG = 112;
		public const int RE_LITERAL = 113;
		public const int DOUBLE = 114;
		public const int FLOAT = 115;
		public const int TIMESPAN = 116;
		public const int LINE_CONTINUATION = 117;
		public const int SL_COMMENT = 118;
		public const int ML_COMMENT = 119;
		public const int WS = 120;
		public const int X_RE_LITERAL = 121;
		public const int ESCAPED_EXPRESSION = 122;
		public const int DQS_ESC = 123;
		public const int SQS_ESC = 124;
		public const int SESC = 125;
		public const int RE_CHAR = 126;
		public const int X_RE_CHAR = 127;
		public const int RE_ESC = 128;
		public const int DIGIT_GROUP = 129;
		public const int REVERSE_DIGIT_GROUP = 130;
		public const int ID_PREFIX = 131;
		public const int ID_LETTER = 132;
		public const int DIGIT = 133;
		public const int HEXDIGIT = 134;
		
	}
}
